tryGet method
Tries to get a configuration value for the specified key.
Implementation
@override
(bool, String?) tryGet(String key) {
if (data.containsKey(key)) {
return (true, data[key]);
}
return (false, null);
}
Tries to get a configuration value for the specified key.
@override
(bool, String?) tryGet(String key) {
if (data.containsKey(key)) {
return (true, data[key]);
}
return (false, null);
}