ignore property
Gets or sets a value that indicates whether the exception is rethrown.
true if the exception isn't rethrown; otherwise, false.
Implementation
bool ignore = false;
Gets or sets a value that indicates whether the exception is rethrown.
true if the exception isn't rethrown; otherwise, false.
bool ignore = false;